-----------
PySight API
-----------

Running PySight (``main`` module)
---------------------------------
.. toctree::
    pysight.main

PySight Outputs and Post-Processing
-----------------------------------

.. toctree::
    pysight.nd_hist_generator
    pysight.post_processing

